@@ -37,6 +37,7 @@
 #define headers_end data
 #endif
 
+#include <linux/cache.h>
 #ifndef __ro_after_init
 #define __ro_after_init __read_mostly
 #endif
@@ -69,7 +70,8 @@
 #define ipv6_dst_lookup(a, b, c, d) ipv6_dst_lookup(b, c, d)
 #endif
 
-#if ((LINUX_VERSION_CODE < KERNEL_VERSION(4, 3, 5) && LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0)) || \
+#if (LINUX_VERSION_CODE == KERNEL_VERSION(4, 4, 0) || \
+    (LINUX_VERSION_CODE < KERNEL_VERSION(4, 3, 5) && LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0)) || \
     (LINUX_VERSION_CODE < KERNEL_VERSION(4, 1, 17) && LINUX_VERSION_CODE > KERNEL_VERSION(3, 19, 0)) || \
     (LINUX_VERSION_CODE < KERNEL_VERSION(3, 18, 27) && LINUX_VERSION_CODE >= KERNEL_VERSION(3, 17, 0)) || \
     (LINUX_VERSION_CODE < KERNEL_VERSION(3, 16, 8) && LINUX_VERSION_CODE >= KERNEL_VERSION(3, 15, 0)) || \
@@ -161,7 +163,7 @@ static inline void netif_keep_dst(struct net_device *dev)
 	typeof(type) __percpu *pcpu_stats = alloc_percpu(type);		\
 	if (pcpu_stats)	{						\
 		int __cpu;						\
-		for_each_possible_cpu (__cpu) {				\
+		for_each_possible_cpu(__cpu) {				\
 			typeof(type) *stat;				\
 			stat = per_cpu_ptr(pcpu_stats, __cpu);		\
 			u64_stats_init(&stat->syncp);			\
@@ -452,16 +454,31 @@ static inline struct nlattr **genl_family_attrbuf(const struct genl_family *fami
 #if LINUX_VERSION_CODE < KERNEL_VERSION(4, 14, 0)
 #define get_device_dump(a, b) get_device_dump_real(a, b); \
 static int get_device_dump(a, b) { \
+	int ret; \
 	struct wireguard_device *wg = (struct wireguard_device *)cb->args[0]; \
 	if (!wg) { \
 		int ret = get_device_start(cb); \
 		if (ret) \
 			return ret; \
 	} \
-	return get_device_dump_real(skb, cb); \
+	/* https://patchwork.kernel.org/patch/10046511/ */ \
+	skb->end -= nlmsg_total_size(sizeof(int)); \
+	ret = get_device_dump_real(skb, cb); \
+	skb->end += nlmsg_total_size(sizeof(int)); \
+	return ret; \
 } \
 static int get_device_dump_real(a, b)
 #define COMPAT_CANNOT_USE_NETLINK_START
+#else /* https://patchwork.kernel.org/patch/10046511/ */
+#define get_device_dump(a, b) get_device_dump_real(a, b); \
+static int get_device_dump(a, b) { \
+	int ret; \
+	skb->end -= nlmsg_total_size(sizeof(int)); \
+	ret = get_device_dump_real(skb, cb); \
+	skb->end += nlmsg_total_size(sizeof(int)); \
+	return ret; \
+} \
+static int get_device_dump_real(a, b)
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
@@ -476,6 +493,36 @@ static int get_device_dump_real(a, b)
 #define COMPAT_CANNOT_USE_IFF_NO_QUEUE
 #endif
 
+#if defined(CONFIG_X86_64)
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 4, 0)
+#include <asm/user.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 2, 0)
+#include <asm/xsave.h>
+#include <asm/xcr.h>
+static inline int cpu_has_xfeatures(u64 xfeatures_needed, const char **feature_name)
+{
+	return xgetbv(XCR_XFEATURE_ENABLED_MASK) & xfeatures_needed;
+}
+#endif
+#ifndef XFEATURE_MASK_YMM
+#define XFEATURE_MASK_YMM XSTATE_YMM
+#endif
+#ifndef XFEATURE_MASK_SSE
+#define XFEATURE_MASK_SSE XSTATE_SSE
+#endif
+#endif
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 11, 0)
+struct _____dummy_container { char dev; };
+#define netdev_notifier_info net_device *)data); __attribute((unused)) char _____dummy = ((struct _____dummy_container
+#endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(4, 14, 0)
+#define timer_setup(a, b, c) setup_timer(a, ((void (*)(unsigned long))b), ((unsigned long)a))
+#define from_timer(var, callback_timer, timer_fieldname) container_of(callback_timer, typeof(*var), timer_fieldname)
+#endif
+
 /* https://lkml.org/lkml/2017/6/23/790 */
 #if IS_ENABLED(CONFIG_NF_CONNTRACK)
 #include <linux/ip.h>
